@@ -678,10 +678,10 @@ def remes(base):
     base.rename(columns={'11':'noviembre'},inplace=True)
     base.rename(columns={'12':'diciembre'},inplace=True)
 
-def validar_padron(dire: DataFrame, padweb: DataFrame, ue: DataFrame, nivel: str = 'cod_mod') -> DataFrame:
+def validar_padron(dire: DataFrame, padweb: DataFrame, ue: DataFrame, nivel: str) -> DataFrame:
 
     '''
-    Validaciones del padrón de la intervención donde se verifican: el código local, el nombre del pliego, nombre de la unidad ejecutora, nombre de la ugel y nombre de la institución educativa considerando como dato de validación a los códigos modulares. Se usan como insumos de validación al Padrón web de Escale y a la Base UE UGEL del equipo Analítica de Datos
+    Validaciones del padrón y metas físicas de la intervención donde se verifican: el código local, el nombre del pliego, nombre de la unidad ejecutora, nombre de la ugel y nombre de la institución educativa considerando como dato de validación a los códigos modulares. Se usan como insumos de validación al Padrón web de Escale y a la Base UE UGEL del Equipo Analítica de Datos
 
     dire: DataFrame
         Base de la dirección
@@ -690,15 +690,15 @@ def validar_padron(dire: DataFrame, padweb: DataFrame, ue: DataFrame, nivel: str
         Base del Padrón web
 
     ue: DataFrame
-        Base UE UGEL del equpipo Analítica de Datos
+        Base UE UGEL
 
-    nivel: str, por defecto cod_mod
-        Nivel de contratación de la intervención
+    nivel: str
+        Nivel de en la cual se encuentra el padrón de la intervención, en esta parte se debe indicar si los colegios militares forman parte del padrón
 
     Ejm:
     ----
 
-    >>> metas = ct.validar_padron(dire, padweb, ue, 'ugel')
+    >>> metas = ct.validar_padron(dire, padweb, ue, 'militar_ugel')
 
     '''
 
@@ -706,19 +706,17 @@ def validar_padron(dire: DataFrame, padweb: DataFrame, ue: DataFrame, nivel: str
 
         # Cambio de formato para validación
 
+        dire.cod_mod=dire.cod_mod.astype(int)
         dire.cod_local_dire=dire.cod_local_dire.astype(int)
+        dire.anexo=dire.anexo.astype(int)
 
         # Filtrar para estado igual a activa IE
 
         padweb_a = padweb[padweb.D_ESTADO == 'Activa']
 
-        # Filtrar para instituciones educativas públicas
-
-        padweb_a_p=padweb_a.loc[(padweb_a['GESTION']=='1')|(padweb_a['GESTION']=='2')]
-
         # Establecer df con variables de interés
 
-        padweb_i=padweb_a_p[['COD_MOD','CODOOII','CODLOCAL','ANEXO','CEN_EDU','D_NIV_MOD']]
+        padweb_i=padweb_a[['COD_MOD','CODOOII','CODLOCAL','ANEXO','CEN_EDU','D_NIV_MOD']]
 
         # Verificar tipo de variables
 
@@ -801,7 +799,7 @@ def validar_padron(dire: DataFrame, padweb: DataFrame, ue: DataFrame, nivel: str
         ue_i.rename(columns={'CODOOII':'cod_ugel'},inplace=True)
         ue_i.rename(columns={'NOM_PLIEGO':'nom_pliego'},inplace=True)
         ue_i.rename(columns={'NOM_UE':'nom_ue'},inplace=True)
-        ue_i.rename(columns={'UGEL':'ugel_dire'},inplace=True)
+        ue_i.rename(columns={'UGEL':'ugel'},inplace=True)
 
         # Eliminar NA
 
@@ -813,16 +811,150 @@ def validar_padron(dire: DataFrame, padweb: DataFrame, ue: DataFrame, nivel: str
 
         # Combinar bases usando inner
 
-        dire_padweb_ue=pd.merge(dire, ue_i, on =['ugel_dire'], how ='left',indicator='merge_2')
+        dire_padweb_ue=pd.merge(dire, ue_i, on =['cod_ugel'], how ='left',indicator='merge_2')
 
         # Variables de interés
 
-        bint=dire_padweb_ue[['nom_pliego_dire','nom_pliego','nom_ue_dire','nom_ue','ugel_dire']]
+        bint=dire_padweb_ue[['cod_ugel','nom_pliego_dire','nom_pliego','nom_ue_dire','nom_ue','ugel_dire','ugel']]
 
         # Comparar; out: True
 
         bint['nom_pliego_ver'] = bint['nom_pliego_dire'].eq(bint['nom_pliego'])
         bint['nom_ue_ver'] = bint['nom_ue_dire'].eq(bint['nom_ue'])
+        bint['ugel_ver'] = bint['ugel_dire'].eq(bint['ugel'])
+
+        return bint
+
+    elif nivel == 'militar_cod_mod':
+
+        # Cambio de formato para validación
+
+        dire.cod_mod=dire.cod_mod.astype(int)
+        dire.cod_local_dire=dire.cod_local_dire.astype(int)
+        dire.anexo=dire.anexo.astype(int)
+
+        # Filtrar para estado igual a activa IE
+
+        padweb_a = padweb[padweb.D_ESTADO == 'Activa']
+
+        # Establecer df con variables de interés
+
+        padweb_i=padweb_a[['COD_MOD','CODOOII','CODLOCAL','ANEXO','CEN_EDU','D_NIV_MOD']]
+
+        # Verificar tipo de variables
+
+        print(padweb_i.dtypes)
+
+        # Pasar a integer
+
+        padweb_i.COD_MOD=padweb_i.COD_MOD.astype(int)
+        padweb_i.CODOOII=padweb_i.CODOOII.astype(int)
+        padweb_i.ANEXO=padweb_i.ANEXO.astype(int)
+
+        padweb_i.loc[(padweb_i['CODLOCAL'] == ''),'CODLOCAL'] = '0'
+
+        padweb_i.CODLOCAL=padweb_i.CODLOCAL.astype(int)
+
+        # Renombrar variables
+
+        padweb_i.rename(columns={'COD_MOD':'cod_mod'},inplace=True)
+        padweb_i.rename(columns={'CODOOII':'cod_ugel'},inplace=True)
+        padweb_i.rename(columns={'CODLOCAL':'cod_local'},inplace=True)
+        padweb_i.rename(columns={'ANEXO':'anexo'},inplace=True)
+        padweb_i.rename(columns={'CEN_EDU':'nombre_iiee'},inplace=True)
+        padweb_i.rename(columns={'COD_CAR':'cod_car'},inplace=True)
+        padweb_i.rename(columns={'DAREACENSO':'dareacenso'},inplace=True)
+        padweb_i.rename(columns={'D_NIV_MOD':'nivel'},inplace=True)
+
+        # Combinar bases
+
+        dire_padweb=pd.merge(dire, padweb_i, on =['cod_mod','anexo'], how ='left',indicator=True)
+
+        # variables de interés
+
+        ue_i=ue[['PLIEGO','EJECUTORA','CODOOII','NOM_PLIEGO','NOM_UE','UGEL']]
+
+        # Renombrar variables
+
+        ue_i.rename(columns={'PLIEGO':'cod_pliego'},inplace=True)
+        ue_i.rename(columns={'EJECUTORA':'cod_ue'},inplace=True)
+        ue_i.rename(columns={'CODOOII':'cod_ugel'},inplace=True)
+        ue_i.rename(columns={'NOM_PLIEGO':'nom_pliego'},inplace=True)
+        ue_i.rename(columns={'NOM_UE':'nom_ue'},inplace=True)
+        ue_i.rename(columns={'UGEL':'ugel'},inplace=True)
+
+        # Eliminar NA
+
+        ue_i = ue_i.dropna()
+
+        # Eliminar colegios militares
+
+        ue_i.drop(ue_i[ue_i['nom_ue'].str.contains('301. COLEGIO MILITAR')].index, inplace=True)
+
+        # Combinar bases usando inner
+
+        dire_padweb_ue=pd.merge(dire_padweb, ue_i, on =['cod_ugel'], how ='left',indicator='merge_2')
+
+        # Arreglo para colegios militares
+
+        dire_padweb_ue.loc[(dire_padweb_ue['nombre_iiee']=='MILITAR PEDRO RUIZ GALLO') & (dire_padweb_ue['cod_ugel']==200001),'nom_ue'] = '301. COLEGIO MILITAR PEDRO RUIZ GALLO'
+        dire_padweb_ue.loc[(dire_padweb_ue['nombre_iiee']=='MILITAR LEONCIO PRADO') & (dire_padweb_ue['cod_ugel']==70101),'nom_ue'] = '301. COLEGIO MILITAR LEONCIO PRADO'
+
+        # Variables de interés
+
+        bint=dire_padweb_ue[['cod_mod','cod_ugel','cod_local_dire','cod_local','nom_pliego_dire','nom_pliego','nom_ue_dire','nom_ue','ugel_dire','ugel','nombre_iiee_dire','nombre_iiee','nivel']]
+
+        # Comparar suma con el total; out: True
+
+        bint['cod_local_ver'] = bint['cod_local_dire'].eq(bint['cod_local'])
+        bint['nom_pliego_ver'] = bint['nom_pliego_dire'].eq(bint['nom_pliego'])
+        bint['nom_ue_ver'] = bint['nom_ue_dire'].eq(bint['nom_ue'])
+        bint['ugel_ver'] = bint['ugel_dire'].eq(bint['ugel'])
+        bint['nombre_iiee_ver'] = bint['nombre_iiee_dire'].eq(bint['nombre_iiee'])
+
+        return bint
+
+    elif nivel == 'militar_ugel':
+
+        # Variables de interés
+
+        ue_i=ue[['PLIEGO','EJECUTORA','CODOOII','NOM_PLIEGO','NOM_UE','UGEL']]
+
+        # Renombrar variables
+
+        ue_i.rename(columns={'PLIEGO':'cod_pliego'},inplace=True)
+        ue_i.rename(columns={'EJECUTORA':'cod_ue'},inplace=True)
+        ue_i.rename(columns={'CODOOII':'cod_ugel'},inplace=True)
+        ue_i.rename(columns={'NOM_PLIEGO':'nom_pliego'},inplace=True)
+        ue_i.rename(columns={'NOM_UE':'nom_ue'},inplace=True)
+        ue_i.rename(columns={'UGEL':'ugel'},inplace=True)
+
+        # Eliminar NA
+
+        ue_i = ue_i.dropna()
+
+        # Eliminar colegios militares
+
+        ue_i.drop(ue_i[ue_i['nom_ue'].str.contains('301. COLEGIO MILITAR')].index, inplace=True)
+
+        # Combinar bases usando inner
+
+        dire_padweb_ue=pd.merge(dire, ue_i, on =['cod_ugel'], how ='left',indicator='merge_2')
+
+        # Arreglo para colegios militares
+
+        dire_padweb_ue.loc[(dire_padweb_ue['nom_ue_dire']=='301. COLEGIO MILITAR PEDRO RUIZ GALLO'),'nom_ue'] = '301. COLEGIO MILITAR PEDRO RUIZ GALLO'
+        dire_padweb_ue.loc[(dire_padweb_ue['nom_ue_dire']=='301. COLEGIO MILITAR LEONCIO PRADO'),'nom_ue'] = '301. COLEGIO MILITAR LEONCIO PRADO'
+
+        # Variables de interés
+
+        bint=dire_padweb_ue[['cod_ugel','nom_pliego_dire','nom_pliego','nom_ue_dire','nom_ue','ugel_dire','ugel']]
+
+        # Comparar; out: True
+
+        bint['nom_pliego_ver'] = bint['nom_pliego_dire'].eq(bint['nom_pliego'])
+        bint['nom_ue_ver'] = bint['nom_ue_dire'].eq(bint['nom_ue'])
+        bint['ugel_ver'] = bint['ugel_dire'].eq(bint['ugel'])
 
         return bint
 
